@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2024, by Samuel Williams.
+# Copyright, 2019-2025, by Samuel Williams.
 
 source "https://rubygems.org"
 
@@ -10,6 +10,7 @@ gemspec
 group :maintenance, optional: true do
 	gem "bake-gem"
 	gem "bake-modernize"
+	gem "bake-releases"
 	
 	gem "utopia-project"
 end
@@ -22,6 +23,7 @@ group :test do
 	
 	gem "traces"
 	gem "sus-fixtures-async"
+	gem "sus-fixtures-benchmark"
 	
 	gem "bake-test"
 	gem "bake-test-external"
